===============================================
Django Waitinglist
===============================================
.. image:: http://slack.pinaxproject.com/badge.svg
   :target: http://slack.pinaxproject.com/

.. image:: https://img.shields.io/travis/pinax/django-waitinglist.svg
    :target: https://travis-ci.org/pinax/django-waitinglist

.. image:: https://img.shields.io/coveralls/pinax/django-waitinglist.svg
    :target: https://coveralls.io/r/pinax/django-waitinglist

.. image:: https://img.shields.io/pypi/dm/django-waitinglist.svg
    :target:  https://pypi.python.org/pypi/django-waitinglist/

.. image:: https://img.shields.io/pypi/v/django-waitinglist.svg
    :target:  https://pypi.python.org/pypi/django-waitinglist/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/django-waitinglist/


Pinax
--------

Pinax is an open-source platform built on the Django Web Framework. It is an ecosystem of reusable Django apps, themes, and starter project templates. 
This collection can be found at http://pinaxproject.com.

This app was developed as part of the Pinax ecosystem but is just a Django app and can be used independently of other Pinax apps.


django-waitinglist
--------------------

``django-waitinglist`` is a Django waiting list app for running a private beta with cohorts support.


Requirements
--------------

* Django 1.4
* django-appconf (included in ``install_requires``)
* django-user-accounts_ (not included in ``install_requires``)

.. _django-user-accounts: https://github.com/pinax/django-user-accounts



Documentation
---------------

The django-waitinglist documentation is available at http://django-waitinglist.readthedocs.org/. The Pinax documentation is available at http://pinaxproject.com/pinax/.



Code of Conduct
------------------

In order to foster a kind, inclusive, and harassment-free community, the Pinax Project has a code of conduct, which can be found here  http://pinaxproject.com/pinax/code_of_conduct/.


Pinax Project Blog and Twitter
--------------------------------

For updates and news regarding the Pinax Project, please follow us on Twitter at @pinaxproject and check out our blog http://blog.pinaxproject.com.




